# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dapr/proto/runtime/v1/dapr.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from dapr.proto.common.v1 import common_pb2 as dapr_dot_proto_dot_common_dot_v1_dot_common__pb2
from dapr.proto.runtime.v1 import appcallback_pb2 as dapr_dot_proto_dot_runtime_dot_v1_dot_appcallback__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dapr/proto/runtime/v1/dapr.proto\x12\x15\x64\x61pr.proto.runtime.v1\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!dapr/proto/common/v1/common.proto\x1a\'dapr/proto/runtime/v1/appcallback.proto\"X\n\x14InvokeServiceRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x07message\x18\x03 \x01(\x0b\x32#.dapr.proto.common.v1.InvokeRequest\"\xf5\x01\n\x0fGetStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12H\n\x0b\x63onsistency\x18\x03 \x01(\x0e\x32\x33.dapr.proto.common.v1.StateOptions.StateConsistency\x12\x46\n\x08metadata\x18\x04 \x03(\x0b\x32\x34.dapr.proto.runtime.v1.GetStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc9\x01\n\x13GetBulkStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x13\n\x0bparallelism\x18\x03 \x01(\x05\x12J\n\x08metadata\x18\x04 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.GetBulkStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"K\n\x14GetBulkStateResponse\x12\x33\n\x05items\x18\x01 \x03(\x0b\x32$.dapr.proto.runtime.v1.BulkStateItem\"\xbe\x01\n\rBulkStateItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\x12\x44\n\x08metadata\x18\x05 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.BulkStateItem.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x01\n\x10GetStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12G\n\x08metadata\x18\x03 \x03(\x0b\x32\x35.dapr.proto.runtime.v1.GetStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x02\n\x12\x44\x65leteStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12(\n\x04\x65tag\x18\x03 \x01(\x0b\x32\x1a.dapr.proto.common.v1.Etag\x12\x33\n\x07options\x18\x04 \x01(\x0b\x32\".dapr.proto.common.v1.StateOptions\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.DeleteStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x16\x44\x65leteBulkStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12/\n\x06states\x18\x02 \x03(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"W\n\x10SaveStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12/\n\x06states\x18\x02 \x03(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"\xbc\x01\n\x11QueryStateRequest\x12\x1d\n\nstore_name\x18\x01 \x01(\tR\tstoreName\x12\r\n\x05query\x18\x02 \x01(\t\x12H\n\x08metadata\x18\x03 \x03(\x0b\x32\x36.dapr.proto.runtime.v1.QueryStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x0eQueryStateItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xd7\x01\n\x12QueryStateResponse\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.dapr.proto.runtime.v1.QueryStateItem\x12\r\n\x05token\x18\x02 \x01(\t\x12I\n\x08metadata\x18\x03 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.QueryStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x01\n\x13PublishEventRequest\x12\x13\n\x0bpubsub_name\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x19\n\x11\x64\x61ta_content_type\x18\x04 \x01(\t\x12J\n\x08metadata\x18\x05 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.PublishEventRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf5\x01\n\x12\x42ulkPublishRequest\x12\x13\n\x0bpubsub_name\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12?\n\x07\x65ntries\x18\x03 \x03(\x0b\x32..dapr.proto.runtime.v1.BulkPublishRequestEntry\x12I\n\x08metadata\x18\x04 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.BulkPublishRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd1\x01\n\x17\x42ulkPublishRequestEntry\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\x12\r\n\x05\x65vent\x18\x02 \x01(\x0c\x12\x14\n\x0c\x63ontent_type\x18\x03 \x01(\t\x12N\n\x08metadata\x18\x04 \x03(\x0b\x32<.dapr.proto.runtime.v1.BulkPublishRequestEntry.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"c\n\x13\x42ulkPublishResponse\x12L\n\rfailedEntries\x18\x01 \x03(\x0b\x32\x35.dapr.proto.runtime.v1.BulkPublishResponseFailedEntry\"A\n\x1e\x42ulkPublishResponseFailedEntry\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\x84\x02\n!SubscribeTopicEventsRequestAlpha1\x12Z\n\x0finitial_request\x18\x01 \x01(\x0b\x32?.dapr.proto.runtime.v1.SubscribeTopicEventsRequestInitialAlpha1H\x00\x12\\\n\x0f\x65vent_processed\x18\x02 \x01(\x0b\x32\x41.dapr.proto.runtime.v1.SubscribeTopicEventsRequestProcessedAlpha1H\x00\x42%\n#subscribe_topic_events_request_type\"\x96\x02\n(SubscribeTopicEventsRequestInitialAlpha1\x12\x13\n\x0bpubsub_name\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12_\n\x08metadata\x18\x03 \x03(\x0b\x32M.dapr.proto.runtime.v1.SubscribeTopicEventsRequestInitialAlpha1.MetadataEntry\x12\x1e\n\x11\x64\x65\x61\x64_letter_topic\x18\x04 \x01(\tH\x00\x88\x01\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x14\n\x12_dead_letter_topic\"s\n*SubscribeTopicEventsRequestProcessedAlpha1\x12\n\n\x02id\x18\x01 \x01(\t\x12\x39\n\x06status\x18\x02 \x01(\x0b\x32).dapr.proto.runtime.v1.TopicEventResponse\"\xed\x01\n\"SubscribeTopicEventsResponseAlpha1\x12\\\n\x10initial_response\x18\x01 \x01(\x0b\x32@.dapr.proto.runtime.v1.SubscribeTopicEventsResponseInitialAlpha1H\x00\x12\x41\n\revent_message\x18\x02 \x01(\x0b\x32(.dapr.proto.runtime.v1.TopicEventRequestH\x00\x42&\n$subscribe_topic_events_response_type\"+\n)SubscribeTopicEventsResponseInitialAlpha1\"\xc3\x01\n\x14InvokeBindingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12K\n\x08metadata\x18\x03 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.InvokeBindingRequest.MetadataEntry\x12\x11\n\toperation\x18\x04 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x15InvokeBindingResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12L\n\x08metadata\x18\x02 \x03(\x0b\x32:.dapr.proto.runtime.v1.InvokeBindingResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb8\x01\n\x10GetSecretRequest\x12\x1d\n\nstore_name\x18\x01 \x01(\tR\tstoreName\x12\x0b\n\x03key\x18\x02 \x01(\t\x12G\n\x08metadata\x18\x03 \x03(\x0b\x32\x35.dapr.proto.runtime.v1.GetSecretRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x11GetSecretResponse\x12@\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.GetSecretResponse.DataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb3\x01\n\x14GetBulkSecretRequest\x12\x1d\n\nstore_name\x18\x01 \x01(\tR\tstoreName\x12K\n\x08metadata\x18\x02 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.GetBulkSecretRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n\x0eSecretResponse\x12\x43\n\x07secrets\x18\x01 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.SecretResponse.SecretsEntry\x1a.\n\x0cSecretsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb1\x01\n\x15GetBulkSecretResponse\x12\x44\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x36.dapr.proto.runtime.v1.GetBulkSecretResponse.DataEntry\x1aR\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.dapr.proto.runtime.v1.SecretResponse:\x02\x38\x01\"f\n\x1bTransactionalStateOperation\x12\x15\n\roperationType\x18\x01 \x01(\t\x12\x30\n\x07request\x18\x02 \x01(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"\x83\x02\n\x1e\x45xecuteStateTransactionRequest\x12\x11\n\tstoreName\x18\x01 \x01(\t\x12\x46\n\noperations\x18\x02 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.TransactionalStateOperation\x12U\n\x08metadata\x18\x03 \x03(\x0b\x32\x43.dapr.proto.runtime.v1.ExecuteStateTransactionRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbb\x01\n\x19RegisterActorTimerRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x08\x64ue_time\x18\x04 \x01(\tR\x07\x64ueTime\x12\x0e\n\x06period\x18\x05 \x01(\t\x12\x10\n\x08\x63\x61llback\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\x0c\x12\x0b\n\x03ttl\x18\x08 \x01(\t\"e\n\x1bUnregisterActorTimerRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xac\x01\n\x1cRegisterActorReminderRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x08\x64ue_time\x18\x04 \x01(\tR\x07\x64ueTime\x12\x0e\n\x06period\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x0b\n\x03ttl\x18\x07 \x01(\t\"h\n\x1eUnregisterActorReminderRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0c\n\x04name\x18\x03 \x01(\t\"]\n\x14GetActorStateRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xa4\x01\n\x15GetActorStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12L\n\x08metadata\x18\x02 \x03(\x0b\x32:.dapr.proto.runtime.v1.GetActorStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x01\n#ExecuteActorStateTransactionRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12K\n\noperations\x18\x03 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.TransactionalActorStateOperation\"\xf5\x01\n TransactionalActorStateOperation\x12\x15\n\roperationType\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12#\n\x05value\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12W\n\x08metadata\x18\x04 \x03(\x0b\x32\x45.dapr.proto.runtime.v1.TransactionalActorStateOperation.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe8\x01\n\x12InvokeActorRequest\x12\x1d\n\nactor_type\x18\x01 \x01(\tR\tactorType\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\tR\x07\x61\x63torId\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.InvokeActorRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"#\n\x13InvokeActorResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x14\n\x12GetMetadataRequest\"\x9b\x06\n\x13GetMetadataResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12Q\n\x13\x61\x63tive_actors_count\x18\x02 \x03(\x0b\x32(.dapr.proto.runtime.v1.ActiveActorsCountB\x02\x18\x01R\x06\x61\x63tors\x12V\n\x15registered_components\x18\x03 \x03(\x0b\x32+.dapr.proto.runtime.v1.RegisteredComponentsR\ncomponents\x12\x65\n\x11\x65xtended_metadata\x18\x04 \x03(\x0b\x32@.dapr.proto.runtime.v1.GetMetadataResponse.ExtendedMetadataEntryR\x08\x65xtended\x12O\n\rsubscriptions\x18\x05 \x03(\x0b\x32).dapr.proto.runtime.v1.PubsubSubscriptionR\rsubscriptions\x12R\n\x0ehttp_endpoints\x18\x06 \x03(\x0b\x32+.dapr.proto.runtime.v1.MetadataHTTPEndpointR\rhttpEndpoints\x12j\n\x19\x61pp_connection_properties\x18\x07 \x01(\x0b\x32..dapr.proto.runtime.v1.AppConnectionPropertiesR\x17\x61ppConnectionProperties\x12\'\n\x0fruntime_version\x18\x08 \x01(\tR\x0eruntimeVersion\x12)\n\x10\x65nabled_features\x18\t \x03(\tR\x0f\x65nabledFeatures\x12H\n\ractor_runtime\x18\n \x01(\x0b\x32#.dapr.proto.runtime.v1.ActorRuntimeR\x0c\x61\x63torRuntime\x1a\x37\n\x15\x45xtendedMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x02\n\x0c\x41\x63torRuntime\x12]\n\x0eruntime_status\x18\x01 \x01(\x0e\x32\x36.dapr.proto.runtime.v1.ActorRuntime.ActorRuntimeStatusR\rruntimeStatus\x12M\n\ractive_actors\x18\x02 \x03(\x0b\x32(.dapr.proto.runtime.v1.ActiveActorsCountR\x0c\x61\x63tiveActors\x12\x1d\n\nhost_ready\x18\x03 \x01(\x08R\thostReady\x12\x1c\n\tplacement\x18\x04 \x01(\tR\tplacement\"A\n\x12\x41\x63torRuntimeStatus\x12\x10\n\x0cINITIALIZING\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\"0\n\x11\x41\x63tiveActorsCount\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"Y\n\x14RegisteredComponents\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x14\n\x0c\x63\x61pabilities\x18\x04 \x03(\t\"*\n\x14MetadataHTTPEndpoint\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"\xd1\x01\n\x17\x41ppConnectionProperties\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\'\n\x0f\x63hannel_address\x18\x03 \x01(\tR\x0e\x63hannelAddress\x12\'\n\x0fmax_concurrency\x18\x04 \x01(\x05R\x0emaxConcurrency\x12\x44\n\x06health\x18\x05 \x01(\x0b\x32\x34.dapr.proto.runtime.v1.AppConnectionHealthProperties\"\xdc\x01\n\x1d\x41ppConnectionHealthProperties\x12*\n\x11health_check_path\x18\x01 \x01(\tR\x0fhealthCheckPath\x12\x32\n\x15health_probe_interval\x18\x02 \x01(\tR\x13healthProbeInterval\x12\x30\n\x14health_probe_timeout\x18\x03 \x01(\tR\x12healthProbeTimeout\x12)\n\x10health_threshold\x18\x04 \x01(\x05R\x0fhealthThreshold\"\x86\x03\n\x12PubsubSubscription\x12\x1f\n\x0bpubsub_name\x18\x01 \x01(\tR\npubsubname\x12\x14\n\x05topic\x18\x02 \x01(\tR\x05topic\x12S\n\x08metadata\x18\x03 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.PubsubSubscription.MetadataEntryR\x08metadata\x12\x44\n\x05rules\x18\x04 \x01(\x0b\x32..dapr.proto.runtime.v1.PubsubSubscriptionRulesR\x05rules\x12*\n\x11\x64\x65\x61\x64_letter_topic\x18\x05 \x01(\tR\x0f\x64\x65\x61\x64LetterTopic\x12\x41\n\x04type\x18\x06 \x01(\x0e\x32-.dapr.proto.runtime.v1.PubsubSubscriptionTypeR\x04type\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n\x17PubsubSubscriptionRules\x12<\n\x05rules\x18\x01 \x03(\x0b\x32-.dapr.proto.runtime.v1.PubsubSubscriptionRule\"5\n\x16PubsubSubscriptionRule\x12\r\n\x05match\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"0\n\x12SetMetadataRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xbc\x01\n\x17GetConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12N\n\x08metadata\x18\x03 \x03(\x0b\x32<.dapr.proto.runtime.v1.GetConfigurationRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x01\n\x18GetConfigurationResponse\x12I\n\x05items\x18\x01 \x03(\x0b\x32:.dapr.proto.runtime.v1.GetConfigurationResponse.ItemsEntry\x1aU\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.dapr.proto.common.v1.ConfigurationItem:\x02\x38\x01\"\xc8\x01\n\x1dSubscribeConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12T\n\x08metadata\x18\x03 \x03(\x0b\x32\x42.dapr.proto.runtime.v1.SubscribeConfigurationRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n\x1fUnsubscribeConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\xd4\x01\n\x1eSubscribeConfigurationResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12O\n\x05items\x18\x02 \x03(\x0b\x32@.dapr.proto.runtime.v1.SubscribeConfigurationResponse.ItemsEntry\x1aU\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.dapr.proto.common.v1.ConfigurationItem:\x02\x38\x01\"?\n UnsubscribeConfigurationResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x9b\x01\n\x0eTryLockRequest\x12\x1d\n\nstore_name\x18\x01 \x01(\tR\tstoreName\x12\x1f\n\x0bresource_id\x18\x02 \x01(\tR\nresourceId\x12\x1d\n\nlock_owner\x18\x03 \x01(\tR\tlockOwner\x12*\n\x11\x65xpiry_in_seconds\x18\x04 \x01(\x05R\x0f\x65xpiryInSeconds\"\"\n\x0fTryLockResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"n\n\rUnlockRequest\x12\x1d\n\nstore_name\x18\x01 \x01(\tR\tstoreName\x12\x1f\n\x0bresource_id\x18\x02 \x01(\tR\nresourceId\x12\x1d\n\nlock_owner\x18\x03 \x01(\tR\tlockOwner\"\xae\x01\n\x0eUnlockResponse\x12<\n\x06status\x18\x01 \x01(\x0e\x32,.dapr.proto.runtime.v1.UnlockResponse.Status\"^\n\x06Status\x12\x0b\n\x07SUCCESS\x10\x00\x12\x17\n\x13LOCK_DOES_NOT_EXIST\x10\x01\x12\x1a\n\x16LOCK_BELONGS_TO_OTHERS\x10\x02\x12\x12\n\x0eINTERNAL_ERROR\x10\x03\"\xb0\x01\n\x13SubtleGetKeyRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x44\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x34.dapr.proto.runtime.v1.SubtleGetKeyRequest.KeyFormat\"\x1e\n\tKeyFormat\x12\x07\n\x03PEM\x10\x00\x12\x08\n\x04JSON\x10\x01\"C\n\x14SubtleGetKeyResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\npublic_key\x18\x02 \x01(\tR\tpublicKey\"\xb6\x01\n\x14SubtleEncryptRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x11\n\tplaintext\x18\x02 \x01(\x0c\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12\r\n\x05nonce\x18\x05 \x01(\x0c\x12\'\n\x0f\x61ssociated_data\x18\x06 \x01(\x0cR\x0e\x61ssociatedData\"8\n\x15SubtleEncryptResponse\x12\x12\n\nciphertext\x18\x01 \x01(\x0c\x12\x0b\n\x03tag\x18\x02 \x01(\x0c\"\xc4\x01\n\x14SubtleDecryptRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x12\n\nciphertext\x18\x02 \x01(\x0c\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12\r\n\x05nonce\x18\x05 \x01(\x0c\x12\x0b\n\x03tag\x18\x06 \x01(\x0c\x12\'\n\x0f\x61ssociated_data\x18\x07 \x01(\x0cR\x0e\x61ssociatedData\"*\n\x15SubtleDecryptResponse\x12\x11\n\tplaintext\x18\x01 \x01(\x0c\"\xc8\x01\n\x14SubtleWrapKeyRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12#\n\rplaintext_key\x18\x02 \x01(\x0cR\x0cplaintextKey\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12\r\n\x05nonce\x18\x05 \x01(\x0c\x12\'\n\x0f\x61ssociated_data\x18\x06 \x01(\x0cR\x0e\x61ssociatedData\"E\n\x15SubtleWrapKeyResponse\x12\x1f\n\x0bwrapped_key\x18\x01 \x01(\x0cR\nwrappedKey\x12\x0b\n\x03tag\x18\x02 \x01(\x0c\"\xd3\x01\n\x16SubtleUnwrapKeyRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x1f\n\x0bwrapped_key\x18\x02 \x01(\x0cR\nwrappedKey\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12\r\n\x05nonce\x18\x05 \x01(\x0c\x12\x0b\n\x03tag\x18\x06 \x01(\x0c\x12\'\n\x0f\x61ssociated_data\x18\x07 \x01(\x0cR\x0e\x61ssociatedData\">\n\x17SubtleUnwrapKeyResponse\x12#\n\rplaintext_key\x18\x01 \x01(\x0cR\x0cplaintextKey\"x\n\x11SubtleSignRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x0e\n\x06\x64igest\x18\x02 \x01(\x0c\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\"\'\n\x12SubtleSignResponse\x12\x11\n\tsignature\x18\x01 \x01(\x0c\"\x8d\x01\n\x13SubtleVerifyRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x0e\n\x06\x64igest\x18\x02 \x01(\x0c\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12\x11\n\tsignature\x18\x05 \x01(\x0c\"%\n\x14SubtleVerifyResponse\x12\r\n\x05valid\x18\x01 \x01(\x08\"\x85\x01\n\x0e\x45ncryptRequest\x12=\n\x07options\x18\x01 \x01(\x0b\x32,.dapr.proto.runtime.v1.EncryptRequestOptions\x12\x34\n\x07payload\x18\x02 \x01(\x0b\x32#.dapr.proto.common.v1.StreamPayload\"\xfe\x01\n\x15\x45ncryptRequestOptions\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x19\n\x08key_name\x18\x02 \x01(\tR\x07keyName\x12\x1a\n\x12key_wrap_algorithm\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x61ta_encryption_cipher\x18\n \x01(\t\x12\x37\n\x18omit_decryption_key_name\x18\x0b \x01(\x08R\x15omitDecryptionKeyName\x12.\n\x13\x64\x65\x63ryption_key_name\x18\x0c \x01(\tR\x11\x64\x65\x63ryptionKeyName\"G\n\x0f\x45ncryptResponse\x12\x34\n\x07payload\x18\x01 \x01(\x0b\x32#.dapr.proto.common.v1.StreamPayload\"\x85\x01\n\x0e\x44\x65\x63ryptRequest\x12=\n\x07options\x18\x01 \x01(\x0b\x32,.dapr.proto.runtime.v1.DecryptRequestOptions\x12\x34\n\x07payload\x18\x02 \x01(\x0b\x32#.dapr.proto.common.v1.StreamPayload\"Y\n\x15\x44\x65\x63ryptRequestOptions\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x19\n\x08key_name\x18\x0c \x01(\tR\x07keyName\"G\n\x0f\x44\x65\x63ryptResponse\x12\x34\n\x07payload\x18\x01 \x01(\x0b\x32#.dapr.proto.common.v1.StreamPayload\"d\n\x12GetWorkflowRequest\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceID\x12-\n\x12workflow_component\x18\x02 \x01(\tR\x11workflowComponent\"\x84\x03\n\x13GetWorkflowResponse\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceID\x12#\n\rworkflow_name\x18\x02 \x01(\tR\x0cworkflowName\x12\x39\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x42\n\x0flast_updated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rlastUpdatedAt\x12%\n\x0eruntime_status\x18\x05 \x01(\tR\rruntimeStatus\x12N\n\nproperties\x18\x06 \x03(\x0b\x32:.dapr.proto.runtime.v1.GetWorkflowResponse.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x02\n\x14StartWorkflowRequest\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceID\x12-\n\x12workflow_component\x18\x02 \x01(\tR\x11workflowComponent\x12#\n\rworkflow_name\x18\x03 \x01(\tR\x0cworkflowName\x12I\n\x07options\x18\x04 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.StartWorkflowRequest.OptionsEntry\x12\r\n\x05input\x18\x05 \x01(\x0c\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"8\n\x15StartWorkflowResponse\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceID\"j\n\x18TerminateWorkflowRequest\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceID\x12-\n\x12workflow_component\x18\x02 \x01(\tR\x11workflowComponent\"f\n\x14PauseWorkflowRequest\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceID\x12-\n\x12workflow_component\x18\x02 \x01(\tR\x11workflowComponent\"g\n\x15ResumeWorkflowRequest\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceID\x12-\n\x12workflow_component\x18\x02 \x01(\tR\x11workflowComponent\"\x9e\x01\n\x19RaiseEventWorkflowRequest\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceID\x12-\n\x12workflow_component\x18\x02 \x01(\tR\x11workflowComponent\x12\x1d\n\nevent_name\x18\x03 \x01(\tR\teventName\x12\x12\n\nevent_data\x18\x04 \x01(\x0c\"f\n\x14PurgeWorkflowRequest\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceID\x12-\n\x12workflow_component\x18\x02 \x01(\tR\x11workflowComponent\"\x11\n\x0fShutdownRequest\"\xe8\x01\n\x03Job\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1f\n\x08schedule\x18\x02 \x01(\tH\x00R\x08schedule\x88\x01\x01\x12\x1d\n\x07repeats\x18\x03 \x01(\rH\x01R\x07repeats\x88\x01\x01\x12\x1e\n\x08\x64ue_time\x18\x04 \x01(\tH\x02R\x07\x64ueTime\x88\x01\x01\x12\x15\n\x03ttl\x18\x05 \x01(\tH\x03R\x03ttl\x88\x01\x01\x12(\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x14.google.protobuf.AnyR\x04\x64\x61taB\x0b\n\t_scheduleB\n\n\x08_repeatsB\x0b\n\t_due_timeB\x06\n\x04_ttl\"=\n\x12ScheduleJobRequest\x12\'\n\x03job\x18\x01 \x01(\x0b\x32\x1a.dapr.proto.runtime.v1.Job\"\x15\n\x13ScheduleJobResponse\"\x1d\n\rGetJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"9\n\x0eGetJobResponse\x12\'\n\x03job\x18\x01 \x01(\x0b\x32\x1a.dapr.proto.runtime.v1.Job\" \n\x10\x44\x65leteJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteJobResponse\"\xe7\x03\n\x13\x43onversationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\tcontextID\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x38\n\x06inputs\x18\x03 \x03(\x0b\x32(.dapr.proto.runtime.v1.ConversationInput\x12N\n\nparameters\x18\x04 \x03(\x0b\x32:.dapr.proto.runtime.v1.ConversationRequest.ParametersEntry\x12J\n\x08metadata\x18\x05 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.ConversationRequest.MetadataEntry\x12\x15\n\x08scrubPII\x18\x06 \x01(\x08H\x01\x88\x01\x01\x12\x18\n\x0btemperature\x18\x07 \x01(\x01H\x02\x88\x01\x01\x1aG\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\n_contextIDB\x0b\n\t_scrubPIIB\x0e\n\x0c_temperature\"d\n\x11\x43onversationInput\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\x04role\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08scrubPII\x18\x03 \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_roleB\x0b\n\t_scrubPII\"\xbc\x01\n\x12\x43onversationResult\x12\x0e\n\x06result\x18\x01 \x01(\t\x12M\n\nparameters\x18\x02 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.ConversationResult.ParametersEntry\x1aG\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\"x\n\x14\x43onversationResponse\x12\x16\n\tcontextID\x18\x01 \x01(\tH\x00\x88\x01\x01\x12:\n\x07outputs\x18\x02 \x03(\x0b\x32).dapr.proto.runtime.v1.ConversationResultB\x0c\n\n_contextID*W\n\x16PubsubSubscriptionType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0b\x44\x45\x43LARATIVE\x10\x01\x12\x10\n\x0cPROGRAMMATIC\x10\x02\x12\r\n\tSTREAMING\x10\x03\x32\xbe\x31\n\x04\x44\x61pr\x12\x64\n\rInvokeService\x12+.dapr.proto.runtime.v1.InvokeServiceRequest\x1a$.dapr.proto.common.v1.InvokeResponse\"\x00\x12]\n\x08GetState\x12&.dapr.proto.runtime.v1.GetStateRequest\x1a\'.dapr.proto.runtime.v1.GetStateResponse\"\x00\x12i\n\x0cGetBulkState\x12*.dapr.proto.runtime.v1.GetBulkStateRequest\x1a+.dapr.proto.runtime.v1.GetBulkStateResponse\"\x00\x12N\n\tSaveState\x12\'.dapr.proto.runtime.v1.SaveStateRequest\x1a\x16.google.protobuf.Empty\"\x00\x12i\n\x10QueryStateAlpha1\x12(.dapr.proto.runtime.v1.QueryStateRequest\x1a).dapr.proto.runtime.v1.QueryStateResponse\"\x00\x12R\n\x0b\x44\x65leteState\x12).dapr.proto.runtime.v1.DeleteStateRequest\x1a\x16.google.protobuf.Empty\"\x00\x12Z\n\x0f\x44\x65leteBulkState\x12-.dapr.proto.runtime.v1.DeleteBulkStateRequest\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x17\x45xecuteStateTransaction\x12\x35.dapr.proto.runtime.v1.ExecuteStateTransactionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12T\n\x0cPublishEvent\x12*.dapr.proto.runtime.v1.PublishEventRequest\x1a\x16.google.protobuf.Empty\"\x00\x12q\n\x16\x42ulkPublishEventAlpha1\x12).dapr.proto.runtime.v1.BulkPublishRequest\x1a*.dapr.proto.runtime.v1.BulkPublishResponse\"\x00\x12\x97\x01\n\x1aSubscribeTopicEventsAlpha1\x12\x38.dapr.proto.runtime.v1.SubscribeTopicEventsRequestAlpha1\x1a\x39.dapr.proto.runtime.v1.SubscribeTopicEventsResponseAlpha1\"\x00(\x01\x30\x01\x12l\n\rInvokeBinding\x12+.dapr.proto.runtime.v1.InvokeBindingRequest\x1a,.dapr.proto.runtime.v1.InvokeBindingResponse\"\x00\x12`\n\tGetSecret\x12\'.dapr.proto.runtime.v1.GetSecretRequest\x1a(.dapr.proto.runtime.v1.GetSecretResponse\"\x00\x12l\n\rGetBulkSecret\x12+.dapr.proto.runtime.v1.GetBulkSecretRequest\x1a,.dapr.proto.runtime.v1.GetBulkSecretResponse\"\x00\x12`\n\x12RegisterActorTimer\x12\x30.dapr.proto.runtime.v1.RegisterActorTimerRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x64\n\x14UnregisterActorTimer\x12\x32.dapr.proto.runtime.v1.UnregisterActorTimerRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x15RegisterActorReminder\x12\x33.dapr.proto.runtime.v1.RegisterActorReminderRequest\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x17UnregisterActorReminder\x12\x35.dapr.proto.runtime.v1.UnregisterActorReminderRequest\x1a\x16.google.protobuf.Empty\"\x00\x12l\n\rGetActorState\x12+.dapr.proto.runtime.v1.GetActorStateRequest\x1a,.dapr.proto.runtime.v1.GetActorStateResponse\"\x00\x12t\n\x1c\x45xecuteActorStateTransaction\x12:.dapr.proto.runtime.v1.ExecuteActorStateTransactionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x0bInvokeActor\x12).dapr.proto.runtime.v1.InvokeActorRequest\x1a*.dapr.proto.runtime.v1.InvokeActorResponse\"\x00\x12{\n\x16GetConfigurationAlpha1\x12..dapr.proto.runtime.v1.GetConfigurationRequest\x1a/.dapr.proto.runtime.v1.GetConfigurationResponse\"\x00\x12u\n\x10GetConfiguration\x12..dapr.proto.runtime.v1.GetConfigurationRequest\x1a/.dapr.proto.runtime.v1.GetConfigurationResponse\"\x00\x12\x8f\x01\n\x1cSubscribeConfigurationAlpha1\x12\x34.dapr.proto.runtime.v1.SubscribeConfigurationRequest\x1a\x35.dapr.proto.runtime.v1.SubscribeConfigurationResponse\"\x00\x30\x01\x12\x89\x01\n\x16SubscribeConfiguration\x12\x34.dapr.proto.runtime.v1.SubscribeConfigurationRequest\x1a\x35.dapr.proto.runtime.v1.SubscribeConfigurationResponse\"\x00\x30\x01\x12\x93\x01\n\x1eUnsubscribeConfigurationAlpha1\x12\x36.dapr.proto.runtime.v1.UnsubscribeConfigurationRequest\x1a\x37.dapr.proto.runtime.v1.UnsubscribeConfigurationResponse\"\x00\x12\x8d\x01\n\x18UnsubscribeConfiguration\x12\x36.dapr.proto.runtime.v1.UnsubscribeConfigurationRequest\x1a\x37.dapr.proto.runtime.v1.UnsubscribeConfigurationResponse\"\x00\x12`\n\rTryLockAlpha1\x12%.dapr.proto.runtime.v1.TryLockRequest\x1a&.dapr.proto.runtime.v1.TryLockResponse\"\x00\x12]\n\x0cUnlockAlpha1\x12$.dapr.proto.runtime.v1.UnlockRequest\x1a%.dapr.proto.runtime.v1.UnlockResponse\"\x00\x12\x62\n\rEncryptAlpha1\x12%.dapr.proto.runtime.v1.EncryptRequest\x1a&.dapr.proto.runtime.v1.EncryptResponse(\x01\x30\x01\x12\x62\n\rDecryptAlpha1\x12%.dapr.proto.runtime.v1.DecryptRequest\x1a&.dapr.proto.runtime.v1.DecryptResponse(\x01\x30\x01\x12\x66\n\x0bGetMetadata\x12).dapr.proto.runtime.v1.GetMetadataRequest\x1a*.dapr.proto.runtime.v1.GetMetadataResponse\"\x00\x12R\n\x0bSetMetadata\x12).dapr.proto.runtime.v1.SetMetadataRequest\x1a\x16.google.protobuf.Empty\"\x00\x12m\n\x12SubtleGetKeyAlpha1\x12*.dapr.proto.runtime.v1.SubtleGetKeyRequest\x1a+.dapr.proto.runtime.v1.SubtleGetKeyResponse\x12p\n\x13SubtleEncryptAlpha1\x12+.dapr.proto.runtime.v1.SubtleEncryptRequest\x1a,.dapr.proto.runtime.v1.SubtleEncryptResponse\x12p\n\x13SubtleDecryptAlpha1\x12+.dapr.proto.runtime.v1.SubtleDecryptRequest\x1a,.dapr.proto.runtime.v1.SubtleDecryptResponse\x12p\n\x13SubtleWrapKeyAlpha1\x12+.dapr.proto.runtime.v1.SubtleWrapKeyRequest\x1a,.dapr.proto.runtime.v1.SubtleWrapKeyResponse\x12v\n\x15SubtleUnwrapKeyAlpha1\x12-.dapr.proto.runtime.v1.SubtleUnwrapKeyRequest\x1a..dapr.proto.runtime.v1.SubtleUnwrapKeyResponse\x12g\n\x10SubtleSignAlpha1\x12(.dapr.proto.runtime.v1.SubtleSignRequest\x1a).dapr.proto.runtime.v1.SubtleSignResponse\x12m\n\x12SubtleVerifyAlpha1\x12*.dapr.proto.runtime.v1.SubtleVerifyRequest\x1a+.dapr.proto.runtime.v1.SubtleVerifyResponse\x12u\n\x13StartWorkflowAlpha1\x12+.dapr.proto.runtime.v1.StartWorkflowRequest\x1a,.dapr.proto.runtime.v1.StartWorkflowResponse\"\x03\x88\x02\x01\x12o\n\x11GetWorkflowAlpha1\x12).dapr.proto.runtime.v1.GetWorkflowRequest\x1a*.dapr.proto.runtime.v1.GetWorkflowResponse\"\x03\x88\x02\x01\x12_\n\x13PurgeWorkflowAlpha1\x12+.dapr.proto.runtime.v1.PurgeWorkflowRequest\x1a\x16.google.protobuf.Empty\"\x03\x88\x02\x01\x12g\n\x17TerminateWorkflowAlpha1\x12/.dapr.proto.runtime.v1.TerminateWorkflowRequest\x1a\x16.google.protobuf.Empty\"\x03\x88\x02\x01\x12_\n\x13PauseWorkflowAlpha1\x12+.dapr.proto.runtime.v1.PauseWorkflowRequest\x1a\x16.google.protobuf.Empty\"\x03\x88\x02\x01\x12\x61\n\x14ResumeWorkflowAlpha1\x12,.dapr.proto.runtime.v1.ResumeWorkflowRequest\x1a\x16.google.protobuf.Empty\"\x03\x88\x02\x01\x12i\n\x18RaiseEventWorkflowAlpha1\x12\x30.dapr.proto.runtime.v1.RaiseEventWorkflowRequest\x1a\x16.google.protobuf.Empty\"\x03\x88\x02\x01\x12q\n\x12StartWorkflowBeta1\x12+.dapr.proto.runtime.v1.StartWorkflowRequest\x1a,.dapr.proto.runtime.v1.StartWorkflowResponse\"\x00\x12k\n\x10GetWorkflowBeta1\x12).dapr.proto.runtime.v1.GetWorkflowRequest\x1a*.dapr.proto.runtime.v1.GetWorkflowResponse\"\x00\x12[\n\x12PurgeWorkflowBeta1\x12+.dapr.proto.runtime.v1.PurgeWorkflowRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x63\n\x16TerminateWorkflowBeta1\x12/.dapr.proto.runtime.v1.TerminateWorkflowRequest\x1a\x16.google.protobuf.Empty\"\x00\x12[\n\x12PauseWorkflowBeta1\x12+.dapr.proto.runtime.v1.PauseWorkflowRequest\x1a\x16.google.protobuf.Empty\"\x00\x12]\n\x13ResumeWorkflowBeta1\x12,.dapr.proto.runtime.v1.ResumeWorkflowRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x65\n\x17RaiseEventWorkflowBeta1\x12\x30.dapr.proto.runtime.v1.RaiseEventWorkflowRequest\x1a\x16.google.protobuf.Empty\"\x00\x12L\n\x08Shutdown\x12&.dapr.proto.runtime.v1.ShutdownRequest\x1a\x16.google.protobuf.Empty\"\x00\x12l\n\x11ScheduleJobAlpha1\x12).dapr.proto.runtime.v1.ScheduleJobRequest\x1a*.dapr.proto.runtime.v1.ScheduleJobResponse\"\x00\x12]\n\x0cGetJobAlpha1\x12$.dapr.proto.runtime.v1.GetJobRequest\x1a%.dapr.proto.runtime.v1.GetJobResponse\"\x00\x12\x66\n\x0f\x44\x65leteJobAlpha1\x12\'.dapr.proto.runtime.v1.DeleteJobRequest\x1a(.dapr.proto.runtime.v1.DeleteJobResponse\"\x00\x12k\n\x0e\x43onverseAlpha1\x12*.dapr.proto.runtime.v1.ConversationRequest\x1a+.dapr.proto.runtime.v1.ConversationResponse\"\x00\x42i\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.dapr_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _globals['_GETSTATEREQUEST_METADATAENTRY']._options = None
  _globals['_GETSTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._options = None
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_BULKSTATEITEM_METADATAENTRY']._options = None
  _globals['_BULKSTATEITEM_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATERESPONSE_METADATAENTRY']._options = None
  _globals['_GETSTATERESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._options = None
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._options = None
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._options = None
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_PUBLISHEVENTREQUEST_METADATAENTRY']._options = None
  _globals['_PUBLISHEVENTREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_BULKPUBLISHREQUEST_METADATAENTRY']._options = None
  _globals['_BULKPUBLISHREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_BULKPUBLISHREQUESTENTRY_METADATAENTRY']._options = None
  _globals['_BULKPUBLISHREQUESTENTRY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_SUBSCRIBETOPICEVENTSREQUESTINITIALALPHA1_METADATAENTRY']._options = None
  _globals['_SUBSCRIBETOPICEVENTSREQUESTINITIALALPHA1_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._options = None
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._options = None
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSECRETREQUEST_METADATAENTRY']._options = None
  _globals['_GETSECRETREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSECRETRESPONSE_DATAENTRY']._options = None
  _globals['_GETSECRETRESPONSE_DATAENTRY']._serialized_options = b'8\001'
  _globals['_GETBULKSECRETREQUEST_METADATAENTRY']._options = None
  _globals['_GETBULKSECRETREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_SECRETRESPONSE_SECRETSENTRY']._options = None
  _globals['_SECRETRESPONSE_SECRETSENTRY']._serialized_options = b'8\001'
  _globals['_GETBULKSECRETRESPONSE_DATAENTRY']._options = None
  _globals['_GETBULKSECRETRESPONSE_DATAENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._options = None
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETACTORSTATERESPONSE_METADATAENTRY']._options = None
  _globals['_GETACTORSTATERESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_TRANSACTIONALACTORSTATEOPERATION_METADATAENTRY']._options = None
  _globals['_TRANSACTIONALACTORSTATEOPERATION_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INVOKEACTORREQUEST_METADATAENTRY']._options = None
  _globals['_INVOKEACTORREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETMETADATARESPONSE_EXTENDEDMETADATAENTRY']._options = None
  _globals['_GETMETADATARESPONSE_EXTENDEDMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETMETADATARESPONSE'].fields_by_name['active_actors_count']._options = None
  _globals['_GETMETADATARESPONSE'].fields_by_name['active_actors_count']._serialized_options = b'\030\001'
  _globals['_PUBSUBSUBSCRIPTION_METADATAENTRY']._options = None
  _globals['_PUBSUBSUBSCRIPTION_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETCONFIGURATIONREQUEST_METADATAENTRY']._options = None
  _globals['_GETCONFIGURATIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETCONFIGURATIONRESPONSE_ITEMSENTRY']._options = None
  _globals['_GETCONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_options = b'8\001'
  _globals['_SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY']._options = None
  _globals['_SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY']._options = None
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_options = b'8\001'
  _globals['_GETWORKFLOWRESPONSE_PROPERTIESENTRY']._options = None
  _globals['_GETWORKFLOWRESPONSE_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_STARTWORKFLOWREQUEST_OPTIONSENTRY']._options = None
  _globals['_STARTWORKFLOWREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._options = None
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._options = None
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._options = None
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_DAPR'].methods_by_name['StartWorkflowAlpha1']._options = None
  _globals['_DAPR'].methods_by_name['StartWorkflowAlpha1']._serialized_options = b'\210\002\001'
  _globals['_DAPR'].methods_by_name['GetWorkflowAlpha1']._options = None
  _globals['_DAPR'].methods_by_name['GetWorkflowAlpha1']._serialized_options = b'\210\002\001'
  _globals['_DAPR'].methods_by_name['PurgeWorkflowAlpha1']._options = None
  _globals['_DAPR'].methods_by_name['PurgeWorkflowAlpha1']._serialized_options = b'\210\002\001'
  _globals['_DAPR'].methods_by_name['TerminateWorkflowAlpha1']._options = None
  _globals['_DAPR'].methods_by_name['TerminateWorkflowAlpha1']._serialized_options = b'\210\002\001'
  _globals['_DAPR'].methods_by_name['PauseWorkflowAlpha1']._options = None
  _globals['_DAPR'].methods_by_name['PauseWorkflowAlpha1']._serialized_options = b'\210\002\001'
  _globals['_DAPR'].methods_by_name['ResumeWorkflowAlpha1']._options = None
  _globals['_DAPR'].methods_by_name['ResumeWorkflowAlpha1']._serialized_options = b'\210\002\001'
  _globals['_DAPR'].methods_by_name['RaiseEventWorkflowAlpha1']._options = None
  _globals['_DAPR'].methods_by_name['RaiseEventWorkflowAlpha1']._serialized_options = b'\210\002\001'
  _globals['_PUBSUBSUBSCRIPTIONTYPE']._serialized_start=15991
  _globals['_PUBSUBSUBSCRIPTIONTYPE']._serialized_end=16078
  _globals['_INVOKESERVICEREQUEST']._serialized_start=224
  _globals['_INVOKESERVICEREQUEST']._serialized_end=312
  _globals['_GETSTATEREQUEST']._serialized_start=315
  _globals['_GETSTATEREQUEST']._serialized_end=560
  _globals['_GETSTATEREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_GETSTATEREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_GETBULKSTATEREQUEST']._serialized_start=563
  _globals['_GETBULKSTATEREQUEST']._serialized_end=764
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_GETBULKSTATERESPONSE']._serialized_start=766
  _globals['_GETBULKSTATERESPONSE']._serialized_end=841
  _globals['_BULKSTATEITEM']._serialized_start=844
  _globals['_BULKSTATEITEM']._serialized_end=1034
  _globals['_BULKSTATEITEM_METADATAENTRY']._serialized_start=513
  _globals['_BULKSTATEITEM_METADATAENTRY']._serialized_end=560
  _globals['_GETSTATERESPONSE']._serialized_start=1037
  _globals['_GETSTATERESPONSE']._serialized_end=1205
  _globals['_GETSTATERESPONSE_METADATAENTRY']._serialized_start=513
  _globals['_GETSTATERESPONSE_METADATAENTRY']._serialized_end=560
  _globals['_DELETESTATEREQUEST']._serialized_start=1208
  _globals['_DELETESTATEREQUEST']._serialized_end=1480
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_DELETEBULKSTATEREQUEST']._serialized_start=1482
  _globals['_DELETEBULKSTATEREQUEST']._serialized_end=1575
  _globals['_SAVESTATEREQUEST']._serialized_start=1577
  _globals['_SAVESTATEREQUEST']._serialized_end=1664
  _globals['_QUERYSTATEREQUEST']._serialized_start=1667
  _globals['_QUERYSTATEREQUEST']._serialized_end=1855
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_QUERYSTATEITEM']._serialized_start=1857
  _globals['_QUERYSTATEITEM']._serialized_end=1929
  _globals['_QUERYSTATERESPONSE']._serialized_start=1932
  _globals['_QUERYSTATERESPONSE']._serialized_end=2147
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._serialized_start=513
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._serialized_end=560
  _globals['_PUBLISHEVENTREQUEST']._serialized_start=2150
  _globals['_PUBLISHEVENTREQUEST']._serialized_end=2373
  _globals['_PUBLISHEVENTREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_PUBLISHEVENTREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_BULKPUBLISHREQUEST']._serialized_start=2376
  _globals['_BULKPUBLISHREQUEST']._serialized_end=2621
  _globals['_BULKPUBLISHREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_BULKPUBLISHREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_BULKPUBLISHREQUESTENTRY']._serialized_start=2624
  _globals['_BULKPUBLISHREQUESTENTRY']._serialized_end=2833
  _globals['_BULKPUBLISHREQUESTENTRY_METADATAENTRY']._serialized_start=513
  _globals['_BULKPUBLISHREQUESTENTRY_METADATAENTRY']._serialized_end=560
  _globals['_BULKPUBLISHRESPONSE']._serialized_start=2835
  _globals['_BULKPUBLISHRESPONSE']._serialized_end=2934
  _globals['_BULKPUBLISHRESPONSEFAILEDENTRY']._serialized_start=2936
  _globals['_BULKPUBLISHRESPONSEFAILEDENTRY']._serialized_end=3001
  _globals['_SUBSCRIBETOPICEVENTSREQUESTALPHA1']._serialized_start=3004
  _globals['_SUBSCRIBETOPICEVENTSREQUESTALPHA1']._serialized_end=3264
  _globals['_SUBSCRIBETOPICEVENTSREQUESTINITIALALPHA1']._serialized_start=3267
  _globals['_SUBSCRIBETOPICEVENTSREQUESTINITIALALPHA1']._serialized_end=3545
  _globals['_SUBSCRIBETOPICEVENTSREQUESTINITIALALPHA1_METADATAENTRY']._serialized_start=513
  _globals['_SUBSCRIBETOPICEVENTSREQUESTINITIALALPHA1_METADATAENTRY']._serialized_end=560
  _globals['_SUBSCRIBETOPICEVENTSREQUESTPROCESSEDALPHA1']._serialized_start=3547
  _globals['_SUBSCRIBETOPICEVENTSREQUESTPROCESSEDALPHA1']._serialized_end=3662
  _globals['_SUBSCRIBETOPICEVENTSRESPONSEALPHA1']._serialized_start=3665
  _globals['_SUBSCRIBETOPICEVENTSRESPONSEALPHA1']._serialized_end=3902
  _globals['_SUBSCRIBETOPICEVENTSRESPONSEINITIALALPHA1']._serialized_start=3904
  _globals['_SUBSCRIBETOPICEVENTSRESPONSEINITIALALPHA1']._serialized_end=3947
  _globals['_INVOKEBINDINGREQUEST']._serialized_start=3950
  _globals['_INVOKEBINDINGREQUEST']._serialized_end=4145
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_INVOKEBINDINGRESPONSE']._serialized_start=4148
  _globals['_INVOKEBINDINGRESPONSE']._serialized_end=4312
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._serialized_start=513
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._serialized_end=560
  _globals['_GETSECRETREQUEST']._serialized_start=4315
  _globals['_GETSECRETREQUEST']._serialized_end=4499
  _globals['_GETSECRETREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_GETSECRETREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_GETSECRETRESPONSE']._serialized_start=4502
  _globals['_GETSECRETRESPONSE']._serialized_end=4632
  _globals['_GETSECRETRESPONSE_DATAENTRY']._serialized_start=4589
  _globals['_GETSECRETRESPONSE_DATAENTRY']._serialized_end=4632
  _globals['_GETBULKSECRETREQUEST']._serialized_start=4635
  _globals['_GETBULKSECRETREQUEST']._serialized_end=4814
  _globals['_GETBULKSECRETREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_GETBULKSECRETREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_SECRETRESPONSE']._serialized_start=4817
  _globals['_SECRETRESPONSE']._serialized_end=4950
  _globals['_SECRETRESPONSE_SECRETSENTRY']._serialized_start=4904
  _globals['_SECRETRESPONSE_SECRETSENTRY']._serialized_end=4950
  _globals['_GETBULKSECRETRESPONSE']._serialized_start=4953
  _globals['_GETBULKSECRETRESPONSE']._serialized_end=5130
  _globals['_GETBULKSECRETRESPONSE_DATAENTRY']._serialized_start=5048
  _globals['_GETBULKSECRETRESPONSE_DATAENTRY']._serialized_end=5130
  _globals['_TRANSACTIONALSTATEOPERATION']._serialized_start=5132
  _globals['_TRANSACTIONALSTATEOPERATION']._serialized_end=5234
  _globals['_EXECUTESTATETRANSACTIONREQUEST']._serialized_start=5237
  _globals['_EXECUTESTATETRANSACTIONREQUEST']._serialized_end=5496
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_REGISTERACTORTIMERREQUEST']._serialized_start=5499
  _globals['_REGISTERACTORTIMERREQUEST']._serialized_end=5686
  _globals['_UNREGISTERACTORTIMERREQUEST']._serialized_start=5688
  _globals['_UNREGISTERACTORTIMERREQUEST']._serialized_end=5789
  _globals['_REGISTERACTORREMINDERREQUEST']._serialized_start=5792
  _globals['_REGISTERACTORREMINDERREQUEST']._serialized_end=5964
  _globals['_UNREGISTERACTORREMINDERREQUEST']._serialized_start=5966
  _globals['_UNREGISTERACTORREMINDERREQUEST']._serialized_end=6070
  _globals['_GETACTORSTATEREQUEST']._serialized_start=6072
  _globals['_GETACTORSTATEREQUEST']._serialized_end=6165
  _globals['_GETACTORSTATERESPONSE']._serialized_start=6168
  _globals['_GETACTORSTATERESPONSE']._serialized_end=6332
  _globals['_GETACTORSTATERESPONSE_METADATAENTRY']._serialized_start=513
  _globals['_GETACTORSTATERESPONSE_METADATAENTRY']._serialized_end=560
  _globals['_EXECUTEACTORSTATETRANSACTIONREQUEST']._serialized_start=6335
  _globals['_EXECUTEACTORSTATETRANSACTIONREQUEST']._serialized_end=6507
  _globals['_TRANSACTIONALACTORSTATEOPERATION']._serialized_start=6510
  _globals['_TRANSACTIONALACTORSTATEOPERATION']._serialized_end=6755
  _globals['_TRANSACTIONALACTORSTATEOPERATION_METADATAENTRY']._serialized_start=513
  _globals['_TRANSACTIONALACTORSTATEOPERATION_METADATAENTRY']._serialized_end=560
  _globals['_INVOKEACTORREQUEST']._serialized_start=6758
  _globals['_INVOKEACTORREQUEST']._serialized_end=6990
  _globals['_INVOKEACTORREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_INVOKEACTORREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_INVOKEACTORRESPONSE']._serialized_start=6992
  _globals['_INVOKEACTORRESPONSE']._serialized_end=7027
  _globals['_GETMETADATAREQUEST']._serialized_start=7029
  _globals['_GETMETADATAREQUEST']._serialized_end=7049
  _globals['_GETMETADATARESPONSE']._serialized_start=7052
  _globals['_GETMETADATARESPONSE']._serialized_end=7847
  _globals['_GETMETADATARESPONSE_EXTENDEDMETADATAENTRY']._serialized_start=7792
  _globals['_GETMETADATARESPONSE_EXTENDEDMETADATAENTRY']._serialized_end=7847
  _globals['_ACTORRUNTIME']._serialized_start=7850
  _globals['_ACTORRUNTIME']._serialized_end=8166
  _globals['_ACTORRUNTIME_ACTORRUNTIMESTATUS']._serialized_start=8101
  _globals['_ACTORRUNTIME_ACTORRUNTIMESTATUS']._serialized_end=8166
  _globals['_ACTIVEACTORSCOUNT']._serialized_start=8168
  _globals['_ACTIVEACTORSCOUNT']._serialized_end=8216
  _globals['_REGISTEREDCOMPONENTS']._serialized_start=8218
  _globals['_REGISTEREDCOMPONENTS']._serialized_end=8307
  _globals['_METADATAHTTPENDPOINT']._serialized_start=8309
  _globals['_METADATAHTTPENDPOINT']._serialized_end=8351
  _globals['_APPCONNECTIONPROPERTIES']._serialized_start=8354
  _globals['_APPCONNECTIONPROPERTIES']._serialized_end=8563
  _globals['_APPCONNECTIONHEALTHPROPERTIES']._serialized_start=8566
  _globals['_APPCONNECTIONHEALTHPROPERTIES']._serialized_end=8786
  _globals['_PUBSUBSUBSCRIPTION']._serialized_start=8789
  _globals['_PUBSUBSUBSCRIPTION']._serialized_end=9179
  _globals['_PUBSUBSUBSCRIPTION_METADATAENTRY']._serialized_start=513
  _globals['_PUBSUBSUBSCRIPTION_METADATAENTRY']._serialized_end=560
  _globals['_PUBSUBSUBSCRIPTIONRULES']._serialized_start=9181
  _globals['_PUBSUBSUBSCRIPTIONRULES']._serialized_end=9268
  _globals['_PUBSUBSUBSCRIPTIONRULE']._serialized_start=9270
  _globals['_PUBSUBSUBSCRIPTIONRULE']._serialized_end=9323
  _globals['_SETMETADATAREQUEST']._serialized_start=9325
  _globals['_SETMETADATAREQUEST']._serialized_end=9373
  _globals['_GETCONFIGURATIONREQUEST']._serialized_start=9376
  _globals['_GETCONFIGURATIONREQUEST']._serialized_end=9564
  _globals['_GETCONFIGURATIONREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_GETCONFIGURATIONREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_GETCONFIGURATIONRESPONSE']._serialized_start=9567
  _globals['_GETCONFIGURATIONRESPONSE']._serialized_end=9755
  _globals['_GETCONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_start=9670
  _globals['_GETCONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_end=9755
  _globals['_SUBSCRIBECONFIGURATIONREQUEST']._serialized_start=9758
  _globals['_SUBSCRIBECONFIGURATIONREQUEST']._serialized_end=9958
  _globals['_SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_UNSUBSCRIBECONFIGURATIONREQUEST']._serialized_start=9960
  _globals['_UNSUBSCRIBECONFIGURATIONREQUEST']._serialized_end=10025
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE']._serialized_start=10028
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE']._serialized_end=10240
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_start=9670
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_end=9755
  _globals['_UNSUBSCRIBECONFIGURATIONRESPONSE']._serialized_start=10242
  _globals['_UNSUBSCRIBECONFIGURATIONRESPONSE']._serialized_end=10305
  _globals['_TRYLOCKREQUEST']._serialized_start=10308
  _globals['_TRYLOCKREQUEST']._serialized_end=10463
  _globals['_TRYLOCKRESPONSE']._serialized_start=10465
  _globals['_TRYLOCKRESPONSE']._serialized_end=10499
  _globals['_UNLOCKREQUEST']._serialized_start=10501
  _globals['_UNLOCKREQUEST']._serialized_end=10611
  _globals['_UNLOCKRESPONSE']._serialized_start=10614
  _globals['_UNLOCKRESPONSE']._serialized_end=10788
  _globals['_UNLOCKRESPONSE_STATUS']._serialized_start=10694
  _globals['_UNLOCKRESPONSE_STATUS']._serialized_end=10788
  _globals['_SUBTLEGETKEYREQUEST']._serialized_start=10791
  _globals['_SUBTLEGETKEYREQUEST']._serialized_end=10967
  _globals['_SUBTLEGETKEYREQUEST_KEYFORMAT']._serialized_start=10937
  _globals['_SUBTLEGETKEYREQUEST_KEYFORMAT']._serialized_end=10967
  _globals['_SUBTLEGETKEYRESPONSE']._serialized_start=10969
  _globals['_SUBTLEGETKEYRESPONSE']._serialized_end=11036
  _globals['_SUBTLEENCRYPTREQUEST']._serialized_start=11039
  _globals['_SUBTLEENCRYPTREQUEST']._serialized_end=11221
  _globals['_SUBTLEENCRYPTRESPONSE']._serialized_start=11223
  _globals['_SUBTLEENCRYPTRESPONSE']._serialized_end=11279
  _globals['_SUBTLEDECRYPTREQUEST']._serialized_start=11282
  _globals['_SUBTLEDECRYPTREQUEST']._serialized_end=11478
  _globals['_SUBTLEDECRYPTRESPONSE']._serialized_start=11480
  _globals['_SUBTLEDECRYPTRESPONSE']._serialized_end=11522
  _globals['_SUBTLEWRAPKEYREQUEST']._serialized_start=11525
  _globals['_SUBTLEWRAPKEYREQUEST']._serialized_end=11725
  _globals['_SUBTLEWRAPKEYRESPONSE']._serialized_start=11727
  _globals['_SUBTLEWRAPKEYRESPONSE']._serialized_end=11796
  _globals['_SUBTLEUNWRAPKEYREQUEST']._serialized_start=11799
  _globals['_SUBTLEUNWRAPKEYREQUEST']._serialized_end=12010
  _globals['_SUBTLEUNWRAPKEYRESPONSE']._serialized_start=12012
  _globals['_SUBTLEUNWRAPKEYRESPONSE']._serialized_end=12074
  _globals['_SUBTLESIGNREQUEST']._serialized_start=12076
  _globals['_SUBTLESIGNREQUEST']._serialized_end=12196
  _globals['_SUBTLESIGNRESPONSE']._serialized_start=12198
  _globals['_SUBTLESIGNRESPONSE']._serialized_end=12237
  _globals['_SUBTLEVERIFYREQUEST']._serialized_start=12240
  _globals['_SUBTLEVERIFYREQUEST']._serialized_end=12381
  _globals['_SUBTLEVERIFYRESPONSE']._serialized_start=12383
  _globals['_SUBTLEVERIFYRESPONSE']._serialized_end=12420
  _globals['_ENCRYPTREQUEST']._serialized_start=12423
  _globals['_ENCRYPTREQUEST']._serialized_end=12556
  _globals['_ENCRYPTREQUESTOPTIONS']._serialized_start=12559
  _globals['_ENCRYPTREQUESTOPTIONS']._serialized_end=12813
  _globals['_ENCRYPTRESPONSE']._serialized_start=12815
  _globals['_ENCRYPTRESPONSE']._serialized_end=12886
  _globals['_DECRYPTREQUEST']._serialized_start=12889
  _globals['_DECRYPTREQUEST']._serialized_end=13022
  _globals['_DECRYPTREQUESTOPTIONS']._serialized_start=13024
  _globals['_DECRYPTREQUESTOPTIONS']._serialized_end=13113
  _globals['_DECRYPTRESPONSE']._serialized_start=13115
  _globals['_DECRYPTRESPONSE']._serialized_end=13186
  _globals['_GETWORKFLOWREQUEST']._serialized_start=13188
  _globals['_GETWORKFLOWREQUEST']._serialized_end=13288
  _globals['_GETWORKFLOWRESPONSE']._serialized_start=13291
  _globals['_GETWORKFLOWRESPONSE']._serialized_end=13679
  _globals['_GETWORKFLOWRESPONSE_PROPERTIESENTRY']._serialized_start=13630
  _globals['_GETWORKFLOWRESPONSE_PROPERTIESENTRY']._serialized_end=13679
  _globals['_STARTWORKFLOWREQUEST']._serialized_start=13682
  _globals['_STARTWORKFLOWREQUEST']._serialized_end=13959
  _globals['_STARTWORKFLOWREQUEST_OPTIONSENTRY']._serialized_start=13913
  _globals['_STARTWORKFLOWREQUEST_OPTIONSENTRY']._serialized_end=13959
  _globals['_STARTWORKFLOWRESPONSE']._serialized_start=13961
  _globals['_STARTWORKFLOWRESPONSE']._serialized_end=14017
  _globals['_TERMINATEWORKFLOWREQUEST']._serialized_start=14019
  _globals['_TERMINATEWORKFLOWREQUEST']._serialized_end=14125
  _globals['_PAUSEWORKFLOWREQUEST']._serialized_start=14127
  _globals['_PAUSEWORKFLOWREQUEST']._serialized_end=14229
  _globals['_RESUMEWORKFLOWREQUEST']._serialized_start=14231
  _globals['_RESUMEWORKFLOWREQUEST']._serialized_end=14334
  _globals['_RAISEEVENTWORKFLOWREQUEST']._serialized_start=14337
  _globals['_RAISEEVENTWORKFLOWREQUEST']._serialized_end=14495
  _globals['_PURGEWORKFLOWREQUEST']._serialized_start=14497
  _globals['_PURGEWORKFLOWREQUEST']._serialized_end=14599
  _globals['_SHUTDOWNREQUEST']._serialized_start=14601
  _globals['_SHUTDOWNREQUEST']._serialized_end=14618
  _globals['_JOB']._serialized_start=14621
  _globals['_JOB']._serialized_end=14853
  _globals['_SCHEDULEJOBREQUEST']._serialized_start=14855
  _globals['_SCHEDULEJOBREQUEST']._serialized_end=14916
  _globals['_SCHEDULEJOBRESPONSE']._serialized_start=14918
  _globals['_SCHEDULEJOBRESPONSE']._serialized_end=14939
  _globals['_GETJOBREQUEST']._serialized_start=14941
  _globals['_GETJOBREQUEST']._serialized_end=14970
  _globals['_GETJOBRESPONSE']._serialized_start=14972
  _globals['_GETJOBRESPONSE']._serialized_end=15029
  _globals['_DELETEJOBREQUEST']._serialized_start=15031
  _globals['_DELETEJOBREQUEST']._serialized_end=15063
  _globals['_DELETEJOBRESPONSE']._serialized_start=15065
  _globals['_DELETEJOBRESPONSE']._serialized_end=15084
  _globals['_CONVERSATIONREQUEST']._serialized_start=15087
  _globals['_CONVERSATIONREQUEST']._serialized_end=15574
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._serialized_start=15411
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._serialized_end=15482
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._serialized_start=513
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._serialized_end=560
  _globals['_CONVERSATIONINPUT']._serialized_start=15576
  _globals['_CONVERSATIONINPUT']._serialized_end=15676
  _globals['_CONVERSATIONRESULT']._serialized_start=15679
  _globals['_CONVERSATIONRESULT']._serialized_end=15867
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._serialized_start=15411
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._serialized_end=15482
  _globals['_CONVERSATIONRESPONSE']._serialized_start=15869
  _globals['_CONVERSATIONRESPONSE']._serialized_end=15989
  _globals['_DAPR']._serialized_start=16081
  _globals['_DAPR']._serialized_end=22415
# @@protoc_insertion_point(module_scope)
